##  Features with Code Support
Feature | Code Support | Usage Notes | Detailed Information
---|---|---|---
Automations | Code for script actions | Configure automations that execute custom scripts to update fact sheet fields. Define the script logic in the code editor. You can include other actions in the same automation flow. | [Automations with Scripts](https://help.sap.com/docs/leanix/ea/automations-with-scripts?locale=en-US&state=PRODUCTION&version=CLOUD "Use automations with scripts to update fact sheet fields or call SAP LeanIX APIs. Define the script logic in a script editor in SAP LeanIX.")
Calculations | Code for the calculation logic | Configure calculations to update fact sheet fields based on fact sheet data. Define conditions and logic in the code editor. | [Calculations](https://help.sap.com/docs/leanix/ea/calculations?locale=en-US&state=PRODUCTION&version=CLOUD "Calculations let you populate fact sheet fields based on values from other fields. Use calculation templates for common scenarios or configure your own to define custom logic.")
Webhooks | Code for callbacks in push webhooks | Configure push webhooks to receive event notifications at a target URL. To manipulate the webhook payload before it's sent, define a callback using custom code. | [Callbacks in Push Webhooks](https://help.sap.com/docs/leanix/ea/push-webhooks?locale=en-US&state=PRODUCTION&version=CLOUD#loio535b4b2790d5460fb013b94b6e0bd877__manipulating_the_webhook_payload_using_a_callback)


